import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/analytics/blocs/analytics_tab/analytics_tab_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/analytics/enums/analytics_page_tab.dart';
import 'package:syncrow_web/pages/analytics/modules/analytics/widgets/analytics_date_filter_button.dart';
import 'package:syncrow_web/pages/analytics/modules/analytics/widgets/analytics_page_tab_button.dart';
import 'package:syncrow_web/utils/style.dart';

class AnalyticsPageTabsAndChildren extends StatelessWidget {
  const AnalyticsPageTabsAndChildren({super.key});

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<AnalyticsTabBloc, AnalyticsPageTab>(
      buildWhen: (previous, current) => previous != current,
      builder: (context, selectedTab) => Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisSize: MainAxisSize.min,
        children: [
          Expanded(
            child: Container(
              decoration: subSectionContainerDecoration,
              padding: const EdgeInsets.symmetric(horizontal: 32),
              child: Row(
                mainAxisSize: MainAxisSize.min,
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  Expanded(
                    flex: 4,
                    child: FittedBox(
                      alignment: AlignmentDirectional.centerStart,
                      fit: BoxFit.scaleDown,
                      child: Row(
                        spacing: 32,
                        mainAxisSize: MainAxisSize.min,
                        mainAxisAlignment: MainAxisAlignment.start,
                        crossAxisAlignment: CrossAxisAlignment.center,
                        children: [
                          ...AnalyticsPageTab.values.map(
                            (tab) => AnimatedSwitcher(
                              switchInCurve: Curves.easeIn,
                              duration: const Duration(milliseconds: 200),
                              child: AnalyticsPageTabButton(
                                key: ValueKey(selectedTab),
                                tab: tab,
                                isSelected: tab == selectedTab,
                              ),
                            ),
                          ),
                        ],
                      ),
                    ),
                  ),
                  const Spacer(),
                  const Expanded(
                    flex: 2,
                    child: FittedBox(
                      fit: BoxFit.scaleDown,
                      alignment: AlignmentDirectional.centerEnd,
                      child: AnalyticsDateFilterButton(),
                    ),
                  ),
                ],
              ),
            ),
          ),
          Expanded(
            flex: 8,
            child: AnimatedSwitcher(
              switchInCurve: Curves.easeIn,
              duration: const Duration(milliseconds: 200),
              child: selectedTab.child,
            ),
          ),
        ],
      ),
    );
  }
}
